# Brute force passwords

[![status-badge](https://ci.codeberg.org/api/badges/cap_jmk/kokushibyo/status.svg)](https://ci.codeberg.org/cap_jmk/kokushibyo)
[![Downloads](https://static.pepy.tech/personalized-badge/kokushibyo?period=total&units=international_system&left_color=orange&right_color=blue&left_text=Downloads)](https://pepy.tech/project/kokushibyo)
[![License: GPL v3](https://img.shields.io/badge/License-GPL_v3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
![Python Versions](https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11%20%7C-blue)
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
[![PyPI - Version](https://img.shields.io/pypi/v/kokushibyo.svg)](https://pypi.org/project/kokushibyo)



# Disclaimer

Only for eductational use.

It is just a study project about how fast is the execution with Python3.12 using all available resources
of my machine. It helped me to understand 

* How to keep my applications secure
* How to keep me secure
* How to write better algorithms for AI/ML and my business. 


# Problem: 

Can we use the full capacity of our machine to brute force a string in a smart way? If yes are we at
danger? 

# Install Python 3.12


https://wiki.crowncloud.net/?How_to_Install_Python_3_12_on_Debian_12


# Install keepassxc 

```bash
sudo apt install keepassxc
```

# Setup Example 

```bash
bash example.sh
```
